"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_native_1 = require("react-native");
const core_1 = require("@replyke/core");
const comments_social_core_1 = require("@replyke/comments-social-core");
const ui_core_react_native_1 = require("@replyke/ui-core-react-native");
const Replies_1 = require("./Replies");
const HeartButton_1 = __importDefault(require("./HeartButton"));
const useSheetManager_1 = __importDefault(require("../../../hooks/useSheetManager"));
const Comment = ({ comment: commentFromSection, extraLeftPadding = 0, }) => {
    // Dynamically get the correct Image component and whether it is expo-image.
    const { ImageComponent, isExpo } = (0, ui_core_react_native_1.getImageComponent)();
    const { user } = (0, core_1.useUser)();
    const { handleShallowReply, handleDeepReply, callbacks, highlightedComment } = (0, core_1.useCommentSection)();
    const { styleConfig } = (0, comments_social_core_1.useSocialStyleConfig)();
    const { openCommentOptionsSheet } = (0, useSheetManager_1.default)();
    const { horizontalItemsGap, verticalItemsGap, authorAvatarSize, authorFontSize, authorFontWeight, authorFontColor, fromNowFontSize, fromNowFontColor, commentBodyFontSize, commentBodyFontColor, actionsItemGap, replyButtonFontSize, replyButtonFontWeight, replyButtonFontColor, heartIconSize, heartIconEmptyColor, heartIconFullColor, heartIconPaddingBottom, likesCountFontSize, likesCountFontWeight, likesCountFontColor, } = styleConfig.commentProps;
    const [comment, setComment] = (0, react_1.useState)(commentFromSection);
    const { upvoteComment, removeCommentUpvote } = (0, core_1.useCommentVotes)({
        comment,
        setComment,
    });
    const handleUpvoteComment = () => {
        if (!user) {
            callbacks?.loginRequiredCallback ||
                (() => alert("Please login first."))();
            return;
        }
        if (!user.username && callbacks?.usernameRequiredCallback) {
            callbacks.usernameRequiredCallback();
            return;
        }
        try {
            upvoteComment();
        }
        catch (err) {
            (0, core_1.handleError)(err, "Failed to upvote comment");
        }
    };
    const handleRemoveCommentUpvote = () => {
        if (!user) {
            callbacks?.loginRequiredCallback ||
                (() => alert("Please login first."))();
            return;
        }
        try {
            removeCommentUpvote();
        }
        catch (err) {
            (0, core_1.handleError)(err, "Failed to upvote comment");
        }
    };
    const userUpvotedComment = !!(user && comment.upvotes.includes(user.id));
    const imageStyle = {
        width: (comment.gif?.aspectRatio || 1) < 1
            ? 200
            : 200 * (comment.gif?.aspectRatio || 1),
        height: (comment.gif?.aspectRatio || 1) > 1
            ? 200
            : 200 * (comment.gif?.aspectRatio || 1),
        borderRadius: 4,
        overflow: "hidden",
    };
    const imageProps = isExpo
        ? {
            source: comment.gif?.gifUrl, // expo-image accepts a string
            contentFit: "cover",
            transition: 1000,
            placeholder: comment.gif?.gifPreviewUrl,
        }
        : {
            source: { uri: comment.gif?.gifUrl }, // React Native's Image requires { uri: ... }
        };
    return ((0, jsx_runtime_1.jsxs)(react_native_1.View, { style: {
            paddingVertical: 8,
            backgroundColor: highlightedComment?.comment.id === comment.id
                ? "#dbeafe"
                : "transparent",
        }, children: [(0, jsx_runtime_1.jsx)(react_native_1.Pressable, { onLongPress: () => {
                    react_native_1.Vibration.vibrate(50);
                    openCommentOptionsSheet(comment);
                    react_native_1.Keyboard.dismiss();
                }, style: {
                    ...styles.container,
                    paddingRight: 16,
                    paddingLeft: 16 + extraLeftPadding,
                }, children: (0, jsx_runtime_1.jsxs)(react_native_1.View, { style: [styles.commentHeader, { gap: horizontalItemsGap }], children: [(0, jsx_runtime_1.jsx)(react_native_1.Pressable, { onPress: () => {
                                if (comment.user.id === user?.id) {
                                    callbacks?.currentUserClickCallback?.();
                                }
                                else {
                                    callbacks?.otherUserClickCallback?.(comment.user.id);
                                }
                            }, children: (0, jsx_runtime_1.jsx)(ui_core_react_native_1.UserAvatar, { user: comment.user, borderRadius: authorAvatarSize, size: authorAvatarSize }) }), (0, jsx_runtime_1.jsxs)(react_native_1.View, { style: [styles.commentBody, { gap: verticalItemsGap }], children: [(0, jsx_runtime_1.jsxs)(react_native_1.View, { style: styles.commentMeta, children: [(0, jsx_runtime_1.jsx)(react_native_1.Pressable, { onPress: () => {
                                                if (comment.user.id === user?.id) {
                                                    callbacks?.currentUserClickCallback?.();
                                                }
                                                else {
                                                    callbacks?.otherUserClickCallback?.(comment.user.id);
                                                }
                                            }, children: (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: [
                                                    styles.authorText,
                                                    {
                                                        fontWeight: authorFontWeight,
                                                        fontSize: authorFontSize,
                                                        color: authorFontColor,
                                                    },
                                                ], children: (0, core_1.getUserName)(comment.user, "username") }) }), (0, jsx_runtime_1.jsx)(ui_core_react_native_1.FromNow, { time: comment.createdAt, fontSize: fromNowFontSize, color: fromNowFontColor })] }), comment.content && ((0, jsx_runtime_1.jsx)(react_native_1.Text, { style: [
                                        styles.commentText,
                                        {
                                            fontSize: commentBodyFontSize,
                                            color: commentBodyFontColor,
                                        },
                                    ], children: (0, ui_core_react_native_1.parseContentWithMentions)(comment.content, comment.mentions, user?.id, callbacks?.currentUserClickCallback, callbacks?.otherUserClickCallback) })), comment.gif?.gifUrl && ((0, jsx_runtime_1.jsx)(ImageComponent, { style: imageStyle, ...imageProps })), (0, jsx_runtime_1.jsx)(react_native_1.View, { style: [styles.actionsContainer, { gap: actionsItemGap }], children: (0, jsx_runtime_1.jsx)(react_native_1.TouchableOpacity, { onPress: () => comment.parentId
                                            ? handleShallowReply(comment)
                                            : handleDeepReply(comment), style: styles.replyButton, children: (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: {
                                                color: replyButtonFontColor,
                                                fontSize: replyButtonFontSize,
                                                fontWeight: replyButtonFontWeight,
                                            }, children: "Reply" }) }) })] }), (0, jsx_runtime_1.jsxs)(react_native_1.View, { style: styles.likesContainer, children: [(0, jsx_runtime_1.jsx)(HeartButton_1.default, { userUpvoted: userUpvotedComment, handleUpvote: handleUpvoteComment, handleRemoveUpvote: handleRemoveCommentUpvote, iconSize: heartIconSize, emptyColor: heartIconEmptyColor, fullColor: heartIconFullColor, padding: 4, paddingBottom: heartIconPaddingBottom }), (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: {
                                        fontSize: likesCountFontSize,
                                        color: likesCountFontColor,
                                        fontWeight: likesCountFontWeight,
                                    }, children: comment.upvotes.length })] })] }) }), !comment.parentId && (0, jsx_runtime_1.jsx)(Replies_1.Replies, { commentId: comment.id })] }));
};
const styles = react_native_1.StyleSheet.create({
    container: {
        width: "100%",
    },
    commentHeader: {
        display: "flex",
        flexDirection: "row",
        alignItems: "flex-start",
    },
    commentBody: {
        flex: 1,
        display: "flex",
        flexDirection: "column",
    },
    commentMeta: {
        display: "flex",
        flexDirection: "row",
        alignItems: "baseline",
        gap: 4,
        marginTop: 2,
    },
    authorText: {
    // Custom styles if needed
    },
    commentText: {
    // Custom styles if needed
    },
    actionsContainer: {
        display: "flex",
        flexDirection: "row",
        alignItems: "center",
    },
    replyButton: {
    // Custom styles if needed
    },
    menuButton: {
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
    },
    likesContainer: {
        display: "flex",
        flexDirection: "column",
        alignItems: "center",
    },
});
exports.default = Comment;
//# sourceMappingURL=Comment.js.map