import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { View, Text, Pressable, Alert } from "react-native";
import { useCallback, useMemo } from "react";
import { useUser, useCommentSection } from "@replyke/core";
import { FlagIcon, TrashIcon } from "@replyke/ui-core-react-native";
import BottomSheet, { BottomSheetBackdrop, BottomSheetView, } from "@gorhom/bottom-sheet";
import useSheetManager from "../../hooks/useSheetManager";
const CommentOptionsSheet = () => {
    const { deleteComment } = useCommentSection();
    const { commentOptionsSheetRef, setOptionsComment, closeCommentOptionsSheet, openReportCommentSheet, setReportedComment, optionsComment, } = useSheetManager();
    const { user } = useUser();
    const isOwner = optionsComment && optionsComment.userId === user?.id;
    const snapPoints = useMemo(() => ["100%"], []);
    const handleDeleteComment = () => {
        Alert.alert("Delete comment", // Title
        "Are you sure you want to proceed?", // Message
        [
            {
                text: "Cancel",
                style: "cancel",
                onPress: () => {
                    closeCommentOptionsSheet?.();
                },
            },
            {
                text: "OK",
                onPress: () => {
                    deleteComment?.({ commentId: optionsComment.id });
                    closeCommentOptionsSheet?.();
                },
            },
        ], { cancelable: false } // Prevents closing the alert by tapping outside
        );
    };
    const renderBackdrop = useCallback((props) => (_jsx(BottomSheetBackdrop, { ...props, disappearsOnIndex: -1, appearsOnIndex: 0 })), []);
    return (_jsx(BottomSheet, { ref: commentOptionsSheetRef, index: -1, snapPoints: snapPoints, enablePanDownToClose: true, backdropComponent: renderBackdrop, onChange: (state) => {
            if (state === -1) {
                setOptionsComment?.(null);
            }
        }, backgroundStyle: { backgroundColor: "#18181B" }, handleIndicatorStyle: { backgroundColor: "#fff" }, handleComponent: () => (_jsx(View, { style: {
                paddingHorizontal: 32,
                paddingVertical: 16,
                flexDirection: "row",
                borderBottomWidth: 1,
                borderColor: "#3f3f46",
            }, children: _jsx(Text, { style: {
                    textTransform: "uppercase",
                    color: "#6b7280",
                    fontSize: 14,
                }, children: "comment options" }) })), children: _jsx(BottomSheetView, { style: {
                padding: 16,
            }, children: isOwner ? (_jsxs(Pressable, { onPress: handleDeleteComment, style: {
                    flexDirection: "row",
                    alignItems: "center",
                    gap: 16, // Use "rowGap" if supported; fallback otherwise
                    padding: 12,
                }, children: [_jsx(TrashIcon, { size: 20, color: "#dc2626" }), _jsx(Text, { style: {
                            fontSize: 16,
                            flex: 1,
                            color: "#dc2626",
                        }, children: "Delete" })] })) : (_jsxs(Pressable, { onPress: () => {
                    closeCommentOptionsSheet?.();
                    openReportCommentSheet?.();
                    setReportedComment?.(optionsComment);
                }, style: {
                    flexDirection: "row",
                    alignItems: "center",
                    gap: 16, // Use "rowGap" if supported; fallback otherwise
                    padding: 12,
                }, children: [_jsx(FlagIcon, { size: 20, color: "#9ca3af" }), _jsx(Text, { style: {
                            fontSize: 16,
                            flex: 1,
                            color: "#9ca3af",
                        }, children: "Report" })] })) }) }));
};
export default CommentOptionsSheet;
//# sourceMappingURL=CommentOptionsSheet.js.map